@@ -118,11 +118,15 @@ class DeclarativeColumnsMetaclass(type):
         attrs["base_columns"] = SortedDict(parent_columns)
         # Possibly add some generated columns based on a model
         if opts.model:
+            fields = opts.model._meta.fields
+            if opts.fields:
+                fields = filter(lambda f: f.name in opts.fields, fields)
+
             # We explicitly pass in verbose_name, so that if the table is
             # instantiated with non-queryset data, model field verbose_names
             # are used anyway.
             extra = SortedDict(((f.name, Column(verbose_name=f.verbose_name))
-                                for f in opts.model._meta.fields))
+                                for f in fields))
             attrs["base_columns"].update(extra)
         # Explicit columns override both parent and generated columns
         attrs["base_columns"].update(SortedDict(columns))
@@ -144,12 +148,13 @@ class TableOptions(object):
     variables in this class.
 
     :param options: options for a table
-    :type options: :class:`Meta` on a :class:`.Table`
+    :type  options: :class:`Meta` on a :class:`.Table`
     """
     def __init__(self, options=None):
         super(TableOptions, self).__init__()
         self.attrs = AttributeDict(getattr(options, "attrs", {}))
         self.empty_text = getattr(options, "empty_text", None)
+        self.fields = getattr(options, "fields", ())
         self.exclude = getattr(options, "exclude", ())
         order_by = getattr(options, "order_by", None)
         if isinstance(order_by, basestring):
